"""
    A client library for BotMaker (https://www.botmaker.com/)

    :copyright: © 2019 Cuenca.
    :license: MIT, see LICENSE for more details.
"""
__all__ = ['Client', '__version__']

from .client import Client
from .version import __version__
